
import pandas as pd
import numpy as np
import json, requests
import geopandas as gpd
from dateutil import parser
from dataclient.tsservice import get_curve, TSService

TS_API_URL = 'https://proba-v-mep.esa.int/api/timeseries/v1.0/ts'



class TimeSeries(object):

    def get_capabilities(self):
        product_list = []
        r = requests.get(TS_API_URL)
        products = r.json()
        for i in products['layers']:
            product_list.append([i['name'],i['bounds']])
        return product_list


    def get_time_series_from_geojson(self, coverage_id, geojson_path, start_date, end_date):
        with open(geojson_path) as f:
            data = json.load(f)

        geojson_dataframe = gpd.read_file(geojson_path)
        start_date = parser.parse(start_date)
        end_date = parser.parse(end_date)
        iterable = TSService().timeseries_async(coverage_id, geojson_dataframe, start_date, end_date)
        ts = []
        for i in iterable:
            ts.append(i)
        return pd.DataFrame(ts).T



if __name__ == '__main__':

    ts = TimeSeries()
    products = ts.get_capabilities()
    print(products)

